@@ -1,11 +1,6 @@
 package Bot::BasicBot;
-BEGIN {
-  $Bot::BasicBot::AUTHORITY = 'cpan:HINRIK';
-}
-BEGIN {
-  $Bot::BasicBot::VERSION = '0.89';
-}
-
+our $AUTHORITY = 'cpan:HINRIK';
+$Bot::BasicBot::VERSION = '0.90';
 use strict;
 use warnings;
 
@@ -741,6 +736,7 @@ sub irc_chan_received_state {
     my $return;
     my $mess = {};
     $mess->{who} = $self->nick_strip($nick);
+    $mess->{raw_nick} = $nick;
 
     $mess->{channel} = $channel;
     $mess->{body} = $received; #chanjoin or chanpart
@@ -918,28 +914,41 @@ Bot::BasicBot - simple irc bot baseclass
 
 =head1 SYNOPSIS
 
-  # with all defaults
-  my $bot = Bot::BasicBot->new( channels => ["#bottest"] );
-  $bot->run();
+  #!/usr/bin/perl
+  use strict;
+  use warnings;
 
-  # with all known options
-  my $bot = Bot::BasicBot->new(
+  # Subclass Bot::BasicBot to provide event-handling methods.
+  package UppercaseBot;
+  use base qw(Bot::BasicBot);
 
-    server => "irc.example.com",
-    port   => "6667",
-    channels => ["#bottest"],
+  sub said {
+      my $self      = shift;
+      my $arguments = shift;    # Contains the message that the bot heard.
 
-    nick      => "basicbot",
-    alt_nicks => ["bbot", "simplebot"],
-    username  => "bot",
-    name      => "Yet Another Bot",
+      # The bot will respond by uppercasing the message and echoing it back.
+      $self->say(
+          channel => $arguments->{channel},
+          body    => uc $arguments->{body},
+      );
 
-    ignore_list => [qw(dipsy dadadodo laotse)],
+      # The bot will shut down after responding to a message.
+      $self->shutdown('I have done my job here.');
+  }
 
+  # Create an object of your Bot::BasicBot subclass and call its run method.
+  package main;
+
+  my $bot = UppercaseBot->new(
+      server      => 'irc.example.com',
+      port        => '6667',
+      channels    => ['#bottest'],
+      nick        => 'UppercaseBot',
+      name        => 'John Doe',
+      ignore_list => [ 'laotse', 'georgeburdell' ],
   );
   $bot->run();
 
-
 =head1 DESCRIPTION
 
 Basic bot system designed to make it easy to do simple bots, optionally
@@ -1063,7 +1072,7 @@ This is a do-nothing implementation, override this in your subclass.
 
 =head2 C<chanpart>
 
-Called when someone joins a channel. It receives a hashref argument
+Called when someone parts a channel. It receives a hashref argument
 similar to the one received by said(). The key 'who' is the nick of the
 user who parted, while 'channel' is the channel they parted.
 
@@ -1299,7 +1308,14 @@ one was prefixed. Mostly a shortcut method - it's roughly equivalent to
 
 Takes no arguments. Returns the underlying
 L<POE::Component::IRC::State|POE::Component::IRC::State> object used by
-Bot::BasicBot.
+Bot::BasicBot. Useful for accessing various state methods and for posting
+commands to the component. For example:
+
+ # get the list of nicks in the channel #someplace
+ my @nicks = $bot->pocoirc->channel_list("#someplace");
+
+ # join the channel #otherplace
+ $bot->pocoirc->yield('join', '#otherplace');
 
 =head2 C<channel_data>
 
@@ -1349,7 +1365,7 @@ is an SSL server.  Defaults to 0.
 The local address to use, for multihomed boxes.  Defaults to undef (use whatever
 source IP address the system deigns is appropriate).
 
-=head C<useipv6>
+=head2 C<useipv6>
 
 A boolean to indicate whether IPv6 should be used.  Defaults to undef (use
 IPv4).
@@ -1448,12 +1464,12 @@ a list of strings
 =head2 C<charset_encode>
 
 Converts a list of perl strings into a list of byte sequences, using
-the bot's charset. See L<charset_decode>.
+the bot's charset. See L<C<charset_decode>|/charset_decode>.
 
 =head1 HELP AND SUPPORT
 
-If you have any questions or issues, you can drop by in #poe @
-irc.perl.org, where I (Hinrik) am usually around.
+If you have any questions or issues, you can drop by in #poe or
+#bot-basicbot @ irc.perl.org, where I (Hinrik) am usually around.
 
 =head1 AUTHOR
 
@@ -1482,6 +1498,9 @@ He also sent me changes for the tick event API, which made sense.
 In November 2010, maintainership moved to Hinrik E<Ouml>rn
 SigurE<eth>sson (L<hinrik.sig@gmail.com>).
 
+In April 2017, maintainership moved to David Precious
+(L<davidp@preshweb.co.uk>).
+
 =head1 SEE ALSO
 
 L<POE>, L<POE::Component::IRC>
